@@ -3,8 +3,6 @@
 import requests
 from requests import Response
 
-from rowantree.common.sdk import demand_env_var, demand_env_var_as_float
-
 from .abstract_command import AbstractCommand
 
 
@@ -30,7 +28,7 @@ class HealthGetCommand(AbstractCommand):
         """
 
         response: Response = requests.get(
-            url=f"{demand_env_var(name='ROWANTREE_SERVICE_ENDPOINT')}/health/plain",
-            timeout=demand_env_var_as_float(name="ROWANTREE_SERVICE_TIMEOUT"),
+            url=f"https://api.{self.options.tld}/game/health/plain",
+            timeout=self.options.timeout,
         )
         return bool(response.text)
