@@ -2,8 +2,6 @@
 
 from starlette import status
 
-from rowantree.common.sdk import demand_env_var
-
 from ..contracts.dto.request_status_codes import RequestStatusCodes
 from ..contracts.dto.wrapped_request import WrappedRequest
 from ..contracts.request_verb import RequestVerb
@@ -35,7 +33,7 @@ class MerchantTransformPerformCommand(AbstractCommand):
 
         request: WrappedRequest = WrappedRequest(
             verb=RequestVerb.POST,
-            url=f"{demand_env_var(name='ROWANTREE_SERVICE_ENDPOINT')}/v1/user/{user_guid}/merchant",
+            url=f"https://api.{self.options.tld}/game/v1/user/{user_guid}/merchant",
             statuses=RequestStatusCodes(allow=[status.HTTP_200_OK], reauth=[status.HTTP_401_UNAUTHORIZED], retry=[]),
             data=request.json(by_alias=True),
         )
