@@ -2,7 +2,6 @@
 
 from starlette import status
 
-from rowantree.common.sdk import demand_env_var
 from rowantree.contracts import User
 
 from ...contracts.dto.request_status_codes import RequestStatusCodes
@@ -37,7 +36,7 @@ class UserCreateCommand(AbstractCommand):
         """
         request: WrappedRequest = WrappedRequest(
             verb=RequestVerb.POST,
-            url=f"{demand_env_var(name='ROWANTREE_SERVICE_ENDPOINT')}/v1/user/{user_guid}",
+            url=f"https://api.{self.options.tld}/game/v1/user/{user_guid}",
             statuses=RequestStatusCodes(
                 allow=[status.HTTP_201_CREATED], reauth=[status.HTTP_401_UNAUTHORIZED], retry=[]
             ),
