@@ -1,7 +1,6 @@
 """ User Feature Active Get Command """
 from starlette import status
 
-from rowantree.common.sdk import demand_env_var
 from rowantree.contracts import UserFeatureState
 
 from ...contracts.dto.request_status_codes import RequestStatusCodes
@@ -38,7 +37,7 @@ class UserFeatureActiveGetCommand(AbstractCommand):
 
         request: WrappedRequest = WrappedRequest(
             verb=RequestVerb.GET,
-            url=f"{demand_env_var(name='ROWANTREE_SERVICE_ENDPOINT')}/v1/user/{user_guid}/features/active",
+            url=f"https://api.{self.options.tld}/game/v1/user/{user_guid}/features/active",
             statuses=RequestStatusCodes(allow=[status.HTTP_200_OK], reauth=[status.HTTP_401_UNAUTHORIZED], retry=[]),
         )
         response: dict = self.wrapped_request(request=request)
