@@ -1,7 +1,6 @@
 """ MerchantTransformsGetResponse Definition """
 
-from rowantree.common.sdk import BaseModel
-from rowantree.contracts import StoreType
+from rowantree.contracts import BaseModel, StoreType
 
 
 class MerchantTransformsGetResponse(BaseModel):
