@@ -2,7 +2,8 @@
 The Rowan Tree Service Layer Interface
 This should be used as the primary entry point for interactions.
 """
-
+from rowantree.auth.sdk import AuthenticateUserCommand
+from rowantree.auth.sdk import CommandOptions as AuthCommandOptions
 from rowantree.contracts import ActionQueue, FeatureType, StoreType, User, UserFeatureState, UserState, UserStore
 
 from .commands.action_queue_process import ActionQueueProcessCommand
@@ -22,6 +23,7 @@ from .commands.user.state_get import UserStateGetCommand
 from .commands.user.stores_get import UserStoresGetCommand
 from .commands.user.transport import UserTransportCommand
 from .commands.world_get import WorldStatusGetCommand
+from .contracts.dto.command_options import CommandOptions
 from .contracts.dto.world_status import WorldStatus
 from .contracts.requests.merchant_transform import MerchantTransformRequest
 from .contracts.requests.user.income_set import UserIncomeSetRequest
@@ -36,6 +38,10 @@ class RowanTreeService:
     Provides an interface for access the service layer.
     """
 
+    auth_options: AuthCommandOptions
+    authenticate_user_command: AuthenticateUserCommand
+    options: CommandOptions
+
     user_active_get_command: UserActiveGetCommand
     user_active_set_command: UserActiveSetCommand
 
@@ -59,29 +65,33 @@ class RowanTreeService:
     health_get_command: HealthGetCommand
     world_status_get_command: WorldStatusGetCommand
 
-    def __init__(self):
-        self.user_active_get_command = UserActiveGetCommand()
-        self.user_active_set_command = UserActiveSetCommand()
+    def __init__(self, auth_options: AuthCommandOptions, options: CommandOptions):
+        self.authenticate_user_command = AuthenticateUserCommand(options=auth_options)
 
-        self.user_create_command = UserCreateCommand()
-        self.user_delete_command = UserDeleteCommand()
+        command_options: dict = {"authenticate_user_command": self.authenticate_user_command, "options": options}
 
-        self.user_feature_active_get_command = UserFeatureActiveGetCommand()
-        self.user_features_get_command = UserFeaturesGetCommand()
+        self.user_active_get_command = UserActiveGetCommand(**command_options)
+        self.user_active_set_command = UserActiveSetCommand(**command_options)
 
-        self.user_income_get_command = UserIncomeGetCommand()
-        self.user_income_set_command = UserIncomeSetCommand()
+        self.user_create_command = UserCreateCommand(**command_options)
+        self.user_delete_command = UserDeleteCommand(**command_options)
 
-        self.user_merchant_transforms_get_command = UserMerchantTransformsGetCommand()
-        self.user_population_get_command = UserPopulationGetCommand()
-        self.user_state_get_command = UserStateGetCommand()
-        self.user_stores_get_command = UserStoresGetCommand()
-        self.user_transport_command = UserTransportCommand()
+        self.user_feature_active_get_command = UserFeatureActiveGetCommand(**command_options)
+        self.user_features_get_command = UserFeaturesGetCommand(**command_options)
 
-        self.merchant_transform_perform_command = MerchantTransformPerformCommand()
-        self.health_get_command = HealthGetCommand()
-        self.action_queue_process_command = ActionQueueProcessCommand()
-        self.world_status_get_command = WorldStatusGetCommand()
+        self.user_income_get_command = UserIncomeGetCommand(**command_options)
+        self.user_income_set_command = UserIncomeSetCommand(**command_options)
+
+        self.user_merchant_transforms_get_command = UserMerchantTransformsGetCommand(**command_options)
+        self.user_population_get_command = UserPopulationGetCommand(**command_options)
+        self.user_state_get_command = UserStateGetCommand(**command_options)
+        self.user_stores_get_command = UserStoresGetCommand(**command_options)
+        self.user_transport_command = UserTransportCommand(**command_options)
+
+        self.merchant_transform_perform_command = MerchantTransformPerformCommand(**command_options)
+        self.health_get_command = HealthGetCommand(**command_options)
+        self.action_queue_process_command = ActionQueueProcessCommand(**command_options)
+        self.world_status_get_command = WorldStatusGetCommand(**command_options)
 
     def user_active_get(self, user_guid: str) -> UserActiveGetStatus:
         """
